==> weblog-1_30.tar.gz: weblog/language/japanese/main.php <==
<?php
/**
 * $Id: main.php,v 1.3 2003/10/26 08:28:42 wellwine Exp $
 * Copyright (c) 2003 by Jeremy N. Cowgar <jc@cowgar.com>
 * Copyright (c) 2003 by Hiro SAKAI (http://wellwine.zive.net/)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * You may not change or alter any portion of this comment or credits
 * of supporting developers from this source code or any supporting
 * source code which is considered copyrighted (c) material of the
 * original comment or credit authors.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */

// Basic's
define('_BL_DISABLEHTML', _DISABLEHTML);
define('_BL_TITLE', 'ȥ');
define('_BL_CATEGORY', 'ƥ');
define('_BL_CATEGORIES', 'ƥ');
define('_BL_MAIN', 'ᥤ');
define('_BL_CONTENTS','ȥ');
define('_BL_POST','֥');
define('_BL_PREVIEW',_PREVIEW);
define('_BL_PRIVATE','ץ饤١');
define('_BL_OPTIONS','ץ');
define('_BL_COMMENTS','');
define('_BL_READ_USERS_BLOG','%sΥ֥ɤ');
define('_BL_EDIT',_EDIT);
define('_BL_READ','ɤ');
define('_BL_DELETE',_DELETE);
define('_BL_BLOG','֥');
define('_BL_GATHERING','ʤΥ֥ȥ򽸤Ƥޤ');
define('_BL_GATHERING_SORRY','ޤ󡢥ޥ֥Ͽ桼Τ߻Ѥ뤳ȤǤޤ');
define('_BL_PRIVATE_NOTEXIST_SORRY', 'ޤ󡢤Υȥϥץ饤١Ȥޤ¸ߤޤ');
define('_BL_ENTRY_POSTED','֥ȥ꤬Ƥޤ');
define('_BL_MOST_RECENT','ǿȥ');
define('_BL_ENTRIES_FOR','%sΥȥ');
define('_BL_ENTRY_FOR','%sΥȥ');
define('_BL_NUMBER_OF_READS','');
define('_BL_CONFIRM_DELETE','֥ȥ(%s)Ƥ⤤Ǥ');
define('_BL_BLOG_DELETED','򤵤줿֥ȥϺޤ');
define('_BL_BLOG_NOT_DELETED','򤵤줿֥ȥϺޤǤ¤ǧƤ');
define('_BL_WHOS_BLOG','%sΥ֥');
define('_BL_ANON_CANNOT_POST_SORRY','ޤƸ¤Τ桼ΤƤ뤳ȤǤޤ<br />Ƥ˾ϥȴԤ䤤碌Ƥ');
define('_BL_DELETE_BUTTON',_DELETE);
define('_BL_PREVIEW_BUTTON',_PREVIEW);
define('_BL_POST_BUTTON','');
define('_BL_POST_TOO_SMALL','ȥϺ%dʸɬפǤʤΥȥ%dʸǤƤɲäƤ');
define('_BL_POST_MUST_BE','ȥϺ<b>%d</b>ʸɬפǤ');
define('_BL_CONTINUE_EDITING','Խ³');
define('_BL_RSS_RECENT', 'ǿȥۿ');
define('_BL_RSS_RECENT_FOR', '%sΥȥۿ');

// %s is your site name
define('_BL_INTARTICLE','%sǸḤ֥̂');
define('_BL_INTARTFOUND','ʲ%sǸĤ˶̣֥Ǥ');

define('_BL_PRINTERPAGE','ѥڡ');
define('_BL_SENDSTORY','ͧã');

define('_BL_POSTED', '');
define('_BL_AUTHOR', 'ɮ');
// %s is your site name
define('_BL_COMESFROM', '%sˤƹ¿Υ֥ɤळȤǤޤ');
define('_BL_PARMALINK', 'Υ֥Σգң');

// %s is count
define('_BL_THEREAREINTOTAL', '%sΥȥ꤬ޤ');
define('_BL_NOARCHIVEDESC', 'ȥϤޤ');
define('_BL_ARCHIVE', 'Υ');
define('_BL_ARCHIVE_FOR', '%sβΥ֥');
define('_BL_READS', '');
?>

==> weblog-1_40.tar.gz: weblog/language/japanese/main.php <==
<?php
/**
 * $Id: main.php,v 1.6 2005/03/18 19:08:04 tohokuaiki Exp $
 * Copyright (c) 2003 by Jeremy N. Cowgar <jc@cowgar.com>
 * Copyright (c) 2003 by Hiro SAKAI (http://wellwine.zive.net/)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * You may not change or alter any portion of this comment or credits
 * of supporting developers from this source code or any supporting
 * source code which is considered copyrighted (c) material of the
 * original comment or credit authors.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */

// Basic's
define('_BL_DISABLEHTML', _DISABLEHTML);
define('_BL_TITLE', 'ȥ');
define('_BL_CATEGORY', 'ƥ');
define('_BL_CATEGORIES', 'ƥ');
define('_BL_MAIN', 'ᥤ');
define('_BL_CONTENTS','ȥ');
define('_BL_POST','֥');
define('_BL_PREVIEW',_PREVIEW);
define('_BL_PRIVATE','ץ饤١');
define('_BL_OPTIONS','ץ');
define('_BL_COMMENTS','');
define('_BL_READ_USERS_BLOG','%sΥ֥ɤ');
define('_BL_EDIT',_EDIT);
define('_BL_READ','ɤ');
define('_BL_DELETE',_DELETE);
define('_BL_BLOG','֥');
define('_BL_GATHERING','ʤΥ֥ȥ򽸤Ƥޤ');
define('_BL_GATHERING_SORRY','ޤ󡢥ޥ֥Ͽ桼Τ߻Ѥ뤳ȤǤޤ');
define('_BL_PRIVATE_NOTEXIST_SORRY', 'ޤ󡢤Υȥϥץ饤١Ȥޤ¸ߤޤ');
define('_BL_ENTRY_POSTED','֥ȥ꤬Ƥޤ');
define('_BL_MOST_RECENT','ǿȥ');
define('_BL_ENTRIES_FOR','%sΥȥ');
define('_BL_ENTRY_FOR','%sΥȥ');
define('_BL_NUMBER_OF_READS','');
define('_BL_NUMBER_OF_TRACKBACKS','ȥåХå');
define('_BL_CONFIRM_DELETE','֥ȥ(%s)Ƥ⤤Ǥ');
define('_BL_BLOG_DELETED','򤵤줿֥ȥϺޤ');
define('_BL_BLOG_NOT_DELETED','򤵤줿֥ȥϺޤǤ¤ǧƤ');
define('_BL_WHOS_BLOG','%sΥ֥');
define('_BL_ANON_CANNOT_POST_SORRY','ޤƸ¤Τ桼ΤƤ뤳ȤǤޤ<br />Ƥ˾ϥȴԤ䤤碌Ƥ');
define('_BL_DELETE_BUTTON',_DELETE);
define('_BL_PREVIEW_BUTTON',_PREVIEW);
define('_BL_POST_BUTTON','');
define('_BL_POST_TOO_SMALL','ȥϺ%dʸɬפǤʤΥȥ%dʸǤƤɲäƤ');
define('_BL_POST_MUST_BE','ȥϺ<b>%d</b>ʸɬפǤ');
define('_BL_CONTINUE_EDITING','Խ³');
define('_BL_RSS_RECENT', 'ǿȥۿ');
define('_BL_RSS_RECENT_FOR', '%sΥȥۿ');
define('_BL_UPDATEPING','Ping');
define('_BL_TRACKBACK','ȥåХåURL');
define('_BL_TRACKBACK_DSC','ȥåХåURLʣϲԤǶڤäƤ');
define('_BL_TRACKBACK_ADMIN','ȥåХå');
define('_BL_TRACKBACK_DELETE',_DELETE);

// %s is your site name
define('_BL_INTARTICLE','%sǸḤ֥̂');
define('_BL_INTARTFOUND','ʲ%sǸĤ˶̣֥Ǥ');

define('_BL_PRINTERPAGE','ѥڡ');
define('_BL_SENDSTORY','ͧã');

define('_BL_POSTED', '');
define('_BL_AUTHOR', 'ɮ');
// %s is your site name
define('_BL_COMESFROM', '%sˤƹ¿Υ֥ɤळȤǤޤ');
define('_BL_PARMALINK', 'Υ֥Σգң');

// %s is count
define('_BL_THEREAREINTOTAL', '%sΥȥ꤬ޤ');
define('_BL_NOARCHIVEDESC', 'ȥϤޤ');
define('_BL_ARCHIVE', 'Υ');
define('_BL_ARCHIVE_FOR', '%sβΥ֥');
define('_BL_READS', '');
define('_BL_NEXT', 'Υȥ'); 
define('_BL_PREV', 'Υȥ'); 

// %s is trackback
define('_BL_TRACKBACK_ANOUNCE' , 'ΥȥΥȥåХåURL');
define('_BL_TRACKBACK_TRANSMIT' , 'ΥȥϰʲURL˥ȥåХåƤޤ');
define('_BL_TRACKBACK_RECIEVED' , 'Υȥ꤬ȥåХå');
?>
